.. _spkg_xz:

xz: General-purpose data compression software
=============================================

Description
-----------

XZ Utils is free general-purpose data compression software with a high
compression ratio.

License
-------

Some parts public domain, other parts GNU LGPLv2.1, GNU GPLv2, or GNU
GPLv3.


Upstream Contact
----------------

http://tukaani.org/xz/

Dependencies
------------


Type
----

standard


Dependencies
------------



Version Information
-------------------

package-version.txt::

    5.2.10

See https://repology.org/project/xz/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i xz

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add xz

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install xz

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install xz-utils

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install xz

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install xz

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install xz

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-xz

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install xz

.. tab:: Slackware:

   .. CODE-BLOCK:: bash

       $ sudo slackpkg install xz

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install xz


If the system package is installed, ``./configure`` will check if it can be used.
